<?php

class Ambient_Routee_Helper_Data extends Mage_Core_Helper_Abstract {

    /**
     * Prepare Logs Data
     *
     * @param $message
     * @param $code
     * @param $event
     * @param $uuid
     * @return void
     */
    public function prepareLogsData($message, $code, $event, $uuid)
    {
        try {
            $data = [
                'method' => $event,
                'desc' => $message,
                'code' => $code
            ];
            $this->saveLogs($data, $uuid, $event);
            $this->sendErrorLog($code, $event, $data, $uuid);
        }catch (Exception $exception){}
    }

    /**
     * Save logs to logs DB Table
     *
     * @param $data
     * @param $getUuid
     * @param $event
     * @param $logType
     * @return string
     */
    public function saveLogs($data,$getUuid, $event, $logType='event'){
        try {
            $saveData = array(
                'store_url' => Mage::getBaseUrl(),
                'event_type' => $event,
                'log_type' => $logType,
                'log_data' => json_encode($data),
                'created_at' => gmdate('d-m-Y H:i:s'),
                'is_exported' => 0
            );

            $resource = Mage::getSingleton('core/resource');
            $writeConnection = $resource->getConnection('core_write');
            $tableName = $resource->getTableName('routee_shop_logs');

            $writeConnection->insert($tableName, $saveData);

            return "Data successfully inserted.";
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }

    /**
     * Send error log to Autoforms
     *
     * @param $code
     * @param $event
     * @param $data
     * @param $uuid
     * @param $logType
     * @return void
     */
    public function sendErrorLog($code, $event, $data, $uuid = null, $logType='event') {
        if($code != 200) {
            $apiData = array(
                'mode' => $logType,
                'event' => $event,
                'code' => $code,
                'exception_message' => $data['desc']
            );
            $url = 'https://autoforms.routee.net/u001/log.php';
            $json = Mage::helper('core')->jsonEncode($apiData);

            $c = curl_init();
            curl_setopt($c, CURLOPT_URL, $url);
            curl_setopt($c, CURLOPT_HTTPHEADER, array('Content-Type:application/json'));
            curl_setopt($c, CURLOPT_POST, true);
            curl_setopt($c, CURLOPT_POSTFIELDS, $json);
            curl_setopt($c, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($c, CURLOPT_TIMEOUT, 30);
            $response = curl_exec($c);
            curl_close($c);
        }
    }
}
